@@ -1,6 +1,5 @@
 import logging
 import os
-import typing
 from typing import Any
 
 import yaml
@@ -83,13 +82,24 @@ class YamlConfig(ConfigBase):
 
 
 class ApolloConfig(ConfigBase):
-    def __init__(self, app_id: str, server_url: str, cluster: str = "default"):
+    def __init__(
+        self,
+        app_id: str,
+        server_url: str,
+        cluster: str = "default",
+        cycle_time: int = 300,
+    ):
         logging.info(
             f"init config object [ApolloConfig], app_id: [{app_id}], server_url: [{server_url}], cluster: [{cluster}]"
         )
         self.apollo_client = ApolloClient(
-            app_id=app_id, config_server_url=server_url, cluster=cluster
+            app_id=app_id,
+            config_server_url=server_url,
+            cluster=cluster,
+            cycle_time=cycle_time,
         )
+        # # 启动长监听
+        # self.apollo_client.start()
 
     def _get_config_field(self, field: str):
         value = self.apollo_client.get_value(field)
