@@ -9,7 +9,8 @@ from insnail_ai_tools.mongodb.model.wecom.meta import WecomMessageActionChoices
 class UserRoleChoices(StrChoicesMixin):
     EXTERNAL_USER = "EXTERNAL_USER"  # 外部用户，即客户
     USER = "USER"  # 内部用户
-    ROBOT = "ROBOT"
+    ROBOT = "ROBOT"  # 机器人
+    GROUP = "GROUP"  # 群
 
     @classmethod
     @lru_cache(1024)
@@ -92,7 +93,7 @@ class WecomPersonalMessage(mongoengine.DynamicDocument, MultiDatabaseMixin):
 
     meta = {
         "collection": "wecom_personal_message",
-        "indexes": ["#msg_id", "#msg_type", "msg_time", "create_time"],
+        "indexes": ["#msg_type", "msg_time", "create_time"],
         "abstract": True,
     }
 
