@@ -1,6 +1,9 @@
 from itertools import chain
 
-from wechatpy.enterprise.client.api import WeChatDepartment
+try:
+    from wechatpy.work.client.api import WeChatDepartment
+except ImportError:
+    from wechatpy.enterprise.client.api import WeChatDepartment
 
 
 class WeChatDepartmentChild(WeChatDepartment):
